window.addEventListener('load', function()
{
  API.Init('background');

  // receive message
  API.RecvMsg(function(event)
  {
    switch(event.command)
    {
      case 'googlesearch':  GoogleSearch(event.text); break;
      case 'yandexsearch':  YandexSearch(event.text); break;  
      case 'youtubesearch': YoutubeSearch(event.text); break;      
      case 'openurl':       OpenURL(event.url,event.type); break;
      
      case 'addcurrenturl': if(event.url) AddText(event.url); else AddCurrentURL(); break; 
      case 'addallurl':     AddAllURL();
      case 'addtext':       AddText(event.text); break;
      case 'createscreen':  API.CreateScreen(event.mode); break;
      
      case 'socjoingroup':  SocAction(event.url,'joingroup'); break;
      case 'socshare':      SocAction(event.url,'share'); break;
      case 'soclike':       SocAction(event.url,'like'); break;
      
      case 'setvk':         GetVKInfo(event.user,event.type,event.post,event.count); break; 
      case 'setyt':         GetYtInfo(event.user,event.type,event.data,event.count); break;
      
      case 'changestatus':  API.SetBadge(event.color,event.text); break;
      
      case 'createreport':  API.CreateReport(event.type,event.zdid,event.title,event.task); break;
    }
  });

  // content script localStorage
  chrome.runtime.onMessage.addListener(function(request, sender, callback){
    if(request.command == 'getprefs')
    {
      var values = {};
      for(i in request.data)
        values[i] = API.Prefs(i);
      callback(values);
    }
    else if(request.command == 'setprefs')
    {
      for(i in request.data)
        API.Prefs(i,request.data[i]);
      if(callback)
        callback({});
    }
  });

  // intercept pushHistory
  chrome.webNavigation.onHistoryStateUpdated.addListener(function(details) {
    if(API.Prefs('AutoLogLink') == 1)
    {
      var url = details.url;
      if(/^https?:\/\//i.test(url))
      {
        var url_ = document.createElement("a");
        url_.href = url;
        if(url_.hostname && url_.hostname.length > 0)
        {
          var black = API.Prefs('ReportsBlackDomain');
          black = black.split('\n');
          black = black.filter(function(e){return e});
          if(black.indexOf(url_.hostname) == -1 && ('www.'+black).indexOf(url_.hostname) == -1)
          AddText(url);
        }
      }
    }
  });

  // API key
  var post_data = {};
  post_data.act = 'connect';
  post_data.key = API.Prefs('APIKey');
  post_data.ver = '194';

  API.HTTPRequest('POST','http://taskhelper.biz/api.php','user='+JSON.stringify(post_data),function(data)
  {
    if(typeof data != 'object' || data == null || data.status != 'ok') {API.SetBadge('#ff0000'); return;}
    // API key
    if(data.key && data.key.toString().length == 32) API.Prefs('APIKey',data.key);
    // news
    if(data.news) 
    {
      // if news, open once a day 
      setTimeout(function()
      {
        var curr_t = Math.round(new Date().getTime() / 1000);
        if(API.Prefs('LastNews') == '0' || (parseInt(curr_t - API.Prefs('LastNews')) - 86400) > 0)
        {
          API.Prefs('LastNews',curr_t);
          OpenURL(data.news,'false');
        }
      },API.rndInt(3000,10000));
    }
  });

  // --- search/open ------------------------------------------------ //
  // search in Google
  API.CreateContextMenu('Найти в Google',function(event)
  {
    var text = event.selectionText || event.linkUrl;
    GoogleSearch(text);
  });
  
  function GoogleSearch(text)
  {
    if(!text) return;
    var url = API.Prefs('OpenGoogle').toString().replace('%s',encodeURIComponent(text));
    API.CreateTab(url,API.Prefs('OpenTabType'));
  }

  // search in Yandex
  API.CreateContextMenu('Найти в Yandex',function(event)
  {
    var text = event.selectionText || event.linkUrl;
    YandexSearch(text);
  });
  
  function YandexSearch(text)
  {
    if(!text) return;
    var url = API.Prefs('OpenYandex').toString().replace('%s',encodeURIComponent(text));
    API.CreateTab(url,API.Prefs('OpenTabType'));
  }

  // search in Youtube
  API.CreateContextMenu('Найти в Youtube',function(event)
  {
    var text = event.selectionText || event.linkUrl;
    YoutubeSearch(text);
  });
  
  function YoutubeSearch(text)
  {
    if(!text) return;
    var url = API.Prefs('OpenYoutube').toString().replace('%s',encodeURIComponent(text));
    API.CreateTab(url,API.Prefs('OpenTabType'));
  }

  // open URL
  API.CreateContextMenu('Открыть URL',function(event)
  {
    var url = event.selectionText || event.linkUrl;
    OpenURL(url);
  });

  // open URL (private)
  API.CreateContextMenu('Открыть URL в приватной вкладке',function(event)
  {
    var url = event.selectionText || event.linkUrl;
    OpenURL(url,'true');
  });
  
  function OpenURL(url,type)
  {
    if(!url) return;
    if(type) type = (type == 'true' ? true : false);
    else type = API.Prefs('OpenTabType');
    API.CreateTab(url,type);
  }
  
  API.CreateContextMenu('',function(e){},'separator');

  // --- add to report ---------------------------------------------- //
  // current URL
  API.CreateContextMenu('Добавить текущий URL в отчет',function()
  {
    AddCurrentURL();
  });
  
  function AddCurrentURL()
  {
    API.GetCurrentURL(function(url)
    {
      if(!url) return;
    API.AddToReport(url);
    });   
  }

  // add all URL
  API.CreateContextMenu('Добавить все URL в отчет',function(event)
  {
    AddAllURL();
  });

  function AddAllURL()
  {
    chrome.tabs.query({currentWindow:true},function(tabs)
    {
      for(var i = 0; i < tabs.length; i++)
      {
        if(/^https?:\/\//i.test(tabs[i].url))
        {
          var url_ = document.createElement("a");
          url_.href = tabs[i].url;
          if(url_.hostname && url_.hostname.length > 0)
          {
            var black = API.Prefs('ReportsBlackDomain');
            black = black.split('\n');
            black = black.filter(function(e){return e});
            if(black.indexOf(url_.hostname.replace(/^www\./gm,'')) == -1)
            AddText(tabs[i].url);
          }
        }
      }
    });
  }

  // text/URL
  API.CreateContextMenu('Добавить в отчет',function(event)
  {
    var text = event.selectionText || event.linkUrl;
    AddText(text);
  });
  
  function AddText(text)
  {
    if(!text) return;
    API.AddToReport(text);
  }

  // screenshot
  API.CreateContextMenu('Добавить скриншот',function(event)
  {
    API.CreateScreen('create');
  });
  
  API.CreateContextMenu('',function(e){},'separator');

  // --- paste ------------------------------------------------------ //
  // paste report
  API.CreateContextMenu('Вставить отчет',function(event)
  {
    GetReportText();
  });
  
  function GetReportText()
  {
    API.SendMsg({target:'inj',command:'getreporttext',text:API.GetReport('text')});
  }
  
  API.CreateContextMenu('',function(e){},'separator');

  // --- social network --------------------------------------------- //
  // join to community
  API.CreateContextMenu('Вступить в группу',function(event)
  {
    var url = event.selectionText || event.linkUrl;
    SocAction(url,'joingroup');
  });
  
  // share
  API.CreateContextMenu('Рассказать друзьям',function(event)
  {
    var url = event.selectionText || event.linkUrl;
    SocAction(url,'share');
  });
  
  // like
  API.CreateContextMenu('Лайкнуть',function(event)
  {
    var url = event.selectionText || event.linkUrl;
    SocAction(url,'like');
  });
  
  function SocAction(url,type)
  {
    if(!url) return;
    API.SetBadge('#00BFFF');
    API.Prefs('SocModuleAction',type);
    API.CreateTab(url,API.Prefs('OpenTabType'));
  }

  // open yt
  API.CreateContextMenu('Открыть видео Youtube',function(event)
  {
    API.SendMsg({target:'inj',command:'openytvideos'});
  });

  // --- additional func -------------------------------------------- //
  // get VK info
  function GetVKInfo(user,type,post,count)
  {
    if(API.Prefs('SocModuleActive') == '0') return;
    // set account URL
    if(API.GetReport('text').indexOf('Аккаунт - http://vk.com/'+user)==-1)
    {
      API.HTTPRequest('GET','https://api.vk.com/method/users.get?user_ids='+user+'&v=5.26','',function(data)
      {
        if(typeof data != 'object') return;
        AddText('Аккаунт - http://vk.com/'+user+' ('+data.response[0].first_name+' '+data.response[0].last_name+')');
        GetVKURL();
      });
    }
    else GetVKURL();
    
    function GetVKURL()
    {
      // join
      if(type == 'join')
      {
        AddText('Подписка - http://vk.com/'+post);
        API.SetBadge('#00ff00');
        API.Prefs('SocModuleAction','');
      }
  
      // set share URL
      else if(type == 'share')
      {
        API.HTTPRequest('GET','https://api.vk.com/method/wall.get?domain='+user+'&count=10&filter=all&v=5.26','',function(data)
        {
          if(typeof data != 'object') return;
          var flag = 0;
          for(i in data.response.items)
          {
            if(data.response.items[i].copy_history)
            {
              for(var h in data.response.items[i].copy_history)
              {
                if(data.response.items[i].copy_history[h].from_id+"_"+data.response.items[i].copy_history[h].id == post && flag==0)
                {
                  flag++;
  AddText('Репост - http://vk.com/wall'+data.response.items[i].from_id+'_'+data.response.items[i].id);
                  API.SetBadge('#00ff00');
                  API.Prefs('SocModuleAction','');
                }
              }
            }
          }
        });
      }
  
      // share community
      else if(type == 'sharecomm')
      {
        API.HTTPRequest('GET','https://api.vk.com/method/wall.get?domain='+user+'&count=10&filter=all&v=5.26','',function(data)
        {
          if(typeof data != 'object') return;
          var flag = 0;
          for(i in data.response.items)
          {
            if(data.response.items[i].attachments[0] && data.response.items[i].attachments[0].link && data.response.items[i].attachments[0].link.url.replace(/https?:\/\//i,'') == post && flag == 0)
            {
              flag++;
              AddText('Рассказал о сообществе - http://vk.com/wall'+data.response.items[i].from_id+'_'+data.response.items[i].id);
            }
          }
        });
      }
  
      // like
      else if(type == 'like')
      {
        var text = 'http://vk.com/wall';
        if(post.substr(0,6) == '_reply') post = post.replace('_reply','');
        if(post.substr(0,5) == 'photo') text = 'http://vk.com/';
        AddText('Лайк - '+text+post+' ('+count+')');
        API.SetBadge('#00ff00');
        API.Prefs('SocModuleAction','');
      }

      // share URL
      else if(type == 'shareurl')
      {
        AddText('Поделился ссылкой - http://vk.com/wall'+post);
      }
    }

  }

  // get YT info 
  function GetYtInfo(user,type,data,count)
  {

    // set account URL
    if(API.GetReport('text').indexOf('Канал - https://www.youtube.com/channel/'+user.channel) == -1)
    {
      AddText('Канал - https://www.youtube.com/channel/'+user.channel+' ('+user.name+')');
      GetYTURL();
    }
    else GetYTURL();

    function GetYTURL()
    {
      // subscribe
      if(type == 'subscribe')
      {
        AddText('Подписка - https://www.youtube.com'+data);
      }
      // like
      else if(type == 'like') 
      {
        AddText('Лайк - https://www.youtube.com/watch?v='+data+' ('+count+')');
      }
      
    }
    
  }

});